<?php

namespace Drupal\access_filter\Plugin\AccessFilter\Condition;

use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\Core\Plugin\PluginBase;
use Drupal\access_filter\Plugin\ConditionInterface;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Filter condition using drupal path.
 *
 * @AccessFilterCondition(
 *   id = "path",
 *   description = @Translation("Drupal path."),
 * )
 */
class PathCondition extends PluginBase implements ConditionInterface, ContainerFactoryPluginInterface {

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition
    );
  }

  /**
   * {@inheritdoc}
   */
  public function summary() {
    $regex = !empty($this->configuration['regex']) ? ' [Regex]' : '';
    return $this->configuration['path'] . $regex;
  }

  /**
   * {@inheritdoc}
   */
  public function validateConfiguration($configuration) {
    $errors = array();

    if (!isset($configuration['path']) || !strlen($configuration['path'])) {
      $errors[] = $this->t("'@property' is required.", array('@property' => 'path'));
    }

    return $errors;
  }

  /**
   * {@inheritdoc}
   */
  public function isMatched(Request $request) {
    $path = $request->getPathInfo();
    if (empty($this->configuration['regex'])) {
      return \Drupal::service('path.matcher')->matchPath($path, $this->configuration['path']);
    }
    else {
      return (bool) preg_match($this->configuration['path'], $path);
    }
  }

}
