<?php

namespace Drupal\access_filter\Plugin\AccessFilter\Condition;

use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\Core\Plugin\PluginBase;
use Drupal\access_filter\Plugin\ConditionInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpFoundation\Request;

/**
 * Filter condition using request URI.
 *
 * @AccessFilterCondition(
 *   id = "uri",
 *   description = @Translation("Request URI with query parameters."),
 * )
 */
class UriCondition extends PluginBase implements ConditionInterface, ContainerFactoryPluginInterface {

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition
    );
  }

  /**
   * {@inheritdoc}
   */
  public function summary() {
    $regex = !empty($this->configuration['regex']) ? ' [Regex]' : '';
    return $this->configuration['uri'] . $regex;
  }

  /**
   * {@inheritdoc}
   */
  public function validateConfiguration($configuration) {
    $errors = array();

    if (!isset($configuration['uri']) || !strlen($configuration['uri'])) {
      $errors[] = $this->t("'@property' is required.", array('@property' => 'uri'));
    }

    return $errors;
  }

  /**
   * {@inheritdoc}
   */
  public function isMatched(Request $request) {
    $uri = $request->getUri();
    if (empty($this->configuration['regex'])) {
      return ($uri == $this->configuration['uri']);
    }
    else {
      return (bool) preg_match($this->configuration['uri'], $uri);
    }
  }

}
