<?php

namespace Drupal\access_filter\Plugin;

use Symfony\Component\HttpFoundation\Request;

/**
 * Provides an interface defining a filter rule.
 */
interface RuleInterface {

  /**
   * Get summary text for the rule.
   *
   * @return string
   *   A summary string.
   */
  public function summary();

  /**
   * Validate configuration data.
   *
   * @return array
   *   An array of error messages.
   */
  public function validateConfiguration($configuration);

  /**
   * Check the current access is allowed by the rule.
   *
   * @param Request $request
   *   A request instance.
   *
   * @return bool
   *   Boolean TRUE if access is allowed or FALSE otherwise.
   */
  public function isAllowed(Request $request);

}
